@@ -110,9 +110,10 @@ enum
 {
   PROP_0,
   PROP_CONTAINER,
+  N_PROPERTIES
 };
 
-
+static GParamSpec *properties[N_PROPERTIES];
 static guint glade_base_editor_signals[LAST_SIGNAL] = { 0 };
 
 static GtkVBoxClass *parent_class = NULL;
@@ -796,7 +797,7 @@ glade_base_editor_popup (GladeBaseEditor * editor, GladeWidget * widget)
                             GLADE_BASE_EDITOR_GTYPE, &iter_type,
                             GLADE_BASE_EDITOR_CLASS_NAME, &class_name, -1);
 
-        label = g_strdup_printf (_("Add %s item"), class_name);
+        label = g_strdup_printf (_("Add %s"), class_name);
 
         item = gtk_menu_item_new_with_label (label);
         gtk_widget_show (item);
@@ -828,7 +829,7 @@ glade_base_editor_popup (GladeBaseEditor * editor, GladeWidget * widget)
                             GLADE_BASE_EDITOR_GTYPE, &iter_type,
                             GLADE_BASE_EDITOR_CLASS_NAME, &class_name, -1);
 
-        label = g_strdup_printf (_("Add child %s item"), class_name);
+        label = g_strdup_printf (_("Add child %s"), class_name);
 
         item = gtk_menu_item_new_with_label (label);
         gtk_widget_show (item);
@@ -1230,7 +1231,7 @@ glade_base_editor_set_container (GladeBaseEditor * editor, GObject * container)
 
       glade_signal_editor_load_widget (e->signal_editor, NULL);
 
-      g_object_notify (G_OBJECT (editor), "container");
+      g_object_notify_by_pspec (G_OBJECT (editor), properties[PROP_CONTAINER]);
       return;
     }
 
@@ -1257,7 +1258,7 @@ glade_base_editor_set_container (GladeBaseEditor * editor, GObject * container)
   g_signal_connect (e->project, "changed",
                     G_CALLBACK (glade_base_editor_project_changed), editor);
 
-  g_object_notify (G_OBJECT (editor), "container");
+  g_object_notify_by_pspec (G_OBJECT (editor), properties[PROP_CONTAINER]);
 }
 
 /*************************** GladeBaseEditor Class ****************************/
@@ -1343,6 +1344,10 @@ glade_base_editor_change_type (GladeBaseEditor * editor,
   name = g_strdup (glade_widget_get_name (gchild));
   glade_base_editor_find_child (editor, gchild, &iter);
 
+  /* Delete old widget first, we cant assume the old and new widget can live in 
+   * the same parent simultaniously */
+  glade_base_editor_delegate_delete_child (editor, parent, gchild);
+
   /* Create new widget */
   gchild_new = glade_base_editor_delegate_build_child (editor, parent, type);
 
@@ -1376,9 +1381,6 @@ glade_base_editor_change_type (GladeBaseEditor * editor,
   /* Copy properties */
   glade_widget_copy_properties (gchild_new, gchild, TRUE, TRUE);
 
-  /* Delete old widget */
-  glade_base_editor_delegate_delete_child (editor, parent, gchild);
-
   /* Apply packing properties to the new object 
    * 
    * No need to use GladeCommand here on the newly created widget,
@@ -1400,6 +1402,7 @@ glade_base_editor_change_type (GladeBaseEditor * editor,
   if (GTK_IS_WIDGET (child_new))
     gtk_widget_show_all (GTK_WIDGET (child_new));
 
+  /* XXX We should update the widget name in the visible tree here too */
   gtk_tree_store_set (GTK_TREE_STORE (editor->priv->model), &iter,
                       GLADE_BASE_EDITOR_GWIDGET, gchild_new,
                       GLADE_BASE_EDITOR_OBJECT, child_new,
@@ -1472,12 +1475,15 @@ glade_base_editor_class_init (GladeBaseEditorClass * klass)
   klass->delete_child = glade_base_editor_delete_child_impl;
   klass->move_child = glade_base_editor_move_child;
 
-  g_object_class_install_property (object_class, PROP_CONTAINER,
-                                   g_param_spec_object
-                                   ("container", _("Container"),
-                                    _
-                                    ("The container object this editor is currently editing"),
-                                    G_TYPE_OBJECT, G_PARAM_READWRITE));
+  properties[PROP_CONTAINER] =
+    g_param_spec_object ("container",
+                         _("Container"),
+                         _("The container object this editor is currently editing"),
+                         G_TYPE_OBJECT,
+                         G_PARAM_READWRITE);
+  
+  /* Install all properties */
+  g_object_class_install_properties (object_class, N_PROPERTIES, properties);
 
   /**
    * GladeBaseEditor::child-selected:
@@ -1496,7 +1502,7 @@ glade_base_editor_class_init (GladeBaseEditorClass * klass)
                     G_SIGNAL_RUN_LAST,
                     G_STRUCT_OFFSET (GladeBaseEditorClass, child_selected),
                     NULL, NULL,
-                    glade_marshal_VOID__OBJECT, G_TYPE_NONE, 1, G_TYPE_OBJECT);
+                    _glade_marshal_VOID__OBJECT, G_TYPE_NONE, 1, G_TYPE_OBJECT);
 
   /**
    * GladeBaseEditor::child-change-type:
@@ -1511,8 +1517,8 @@ glade_base_editor_class_init (GladeBaseEditorClass * klass)
                     G_TYPE_FROM_CLASS (object_class),
                     G_SIGNAL_RUN_LAST,
                     G_STRUCT_OFFSET (GladeBaseEditorClass, change_type),
-                    glade_boolean_handled_accumulator, NULL,
-                    glade_marshal_BOOLEAN__OBJECT_UINT,
+                    _glade_boolean_handled_accumulator, NULL,
+                    _glade_marshal_BOOLEAN__OBJECT_UINT,
                     G_TYPE_BOOLEAN, 2, G_TYPE_OBJECT, G_TYPE_UINT);
 
   /**
@@ -1528,8 +1534,8 @@ glade_base_editor_class_init (GladeBaseEditorClass * klass)
                     G_TYPE_FROM_CLASS (object_class),
                     G_SIGNAL_RUN_LAST,
                     G_STRUCT_OFFSET (GladeBaseEditorClass, get_display_name),
-                    glade_string_accumulator, NULL,
-                    glade_marshal_STRING__OBJECT,
+                    _glade_string_accumulator, NULL,
+                    _glade_marshal_STRING__OBJECT,
                     G_TYPE_STRING, 1, G_TYPE_OBJECT);
 
   /**
@@ -1548,8 +1554,8 @@ glade_base_editor_class_init (GladeBaseEditorClass * klass)
                     G_TYPE_FROM_CLASS (object_class),
                     G_SIGNAL_RUN_LAST,
                     G_STRUCT_OFFSET (GladeBaseEditorClass, build_child),
-                    glade_stop_emission_accumulator, NULL,
-                    glade_marshal_OBJECT__OBJECT_UINT,
+                    _glade_stop_emission_accumulator, NULL,
+                    _glade_marshal_OBJECT__OBJECT_UINT,
                     G_TYPE_OBJECT, 2, G_TYPE_OBJECT, G_TYPE_UINT);
 
   /**
@@ -1563,8 +1569,8 @@ glade_base_editor_class_init (GladeBaseEditorClass * klass)
                     G_TYPE_FROM_CLASS (object_class),
                     G_SIGNAL_RUN_LAST,
                     G_STRUCT_OFFSET (GladeBaseEditorClass, delete_child),
-                    glade_boolean_handled_accumulator, NULL,
-                    glade_marshal_BOOLEAN__OBJECT_OBJECT,
+                    _glade_boolean_handled_accumulator, NULL,
+                    _glade_marshal_BOOLEAN__OBJECT_OBJECT,
                     G_TYPE_BOOLEAN, 2, G_TYPE_OBJECT, G_TYPE_OBJECT);
 
   /**
@@ -1582,8 +1588,8 @@ glade_base_editor_class_init (GladeBaseEditorClass * klass)
                     G_TYPE_FROM_CLASS (object_class),
                     G_SIGNAL_RUN_LAST,
                     G_STRUCT_OFFSET (GladeBaseEditorClass, move_child),
-                    glade_stop_emission_accumulator, NULL,
-                    glade_marshal_BOOLEAN__OBJECT_OBJECT,
+                    _glade_stop_emission_accumulator, NULL,
+                    _glade_marshal_BOOLEAN__OBJECT_OBJECT,
                     G_TYPE_BOOLEAN, 2, G_TYPE_OBJECT, G_TYPE_OBJECT);
 }
 
