@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2001 Ximian, Inc.
  * Copyright (C) 2004 Imendio AB
@@ -47,26 +46,10 @@ typedef struct _GladeWidgetGroup GladeWidgetGroup;
  */
 typedef void      (*GladeCatalogInitFunc)    (const gchar *name);
 
-/**
- * GladeProjectConvertFunc:
- * @project: A #GladeProject
- * @new_format: The format to convert @project to
- *
- * Generally format transperency is implemented at load/save time,
- * but if some objects need to be setup differently, or some new
- * objects created (like real GtkAdjustment objects for old inline
- * property values) this is the place to do those things, be careful
- * to use the GladeCommand api because conversions are undoable.
- *
- * Returns: FALSE if any errors occurred during the conversion.
- */
-typedef gboolean  (*GladeProjectConvertFunc) (GladeProject        *project, 
-					      GladeProjectFormat   new_format);
-
 
 typedef struct {
-	gint major;
-	gint minor;
+  gint major;
+  gint minor;
 } GladeTargetableVersion;
 
 
@@ -79,8 +62,8 @@ G_CONST_RETURN gchar  *glade_catalog_get_book       (GladeCatalog     *catalog);
 
 GList        *glade_catalog_get_targets             (GladeCatalog     *catalog);
 
-gint          glade_catalog_get_major_version       (GladeCatalog     *catalog);
-gint          glade_catalog_get_minor_version       (GladeCatalog     *catalog);
+guint16       glade_catalog_get_major_version       (GladeCatalog     *catalog);
+guint16       glade_catalog_get_minor_version       (GladeCatalog     *catalog);
 
 GList        *glade_catalog_get_widget_groups       (GladeCatalog     *catalog);
 
@@ -99,11 +82,6 @@ gboolean      glade_widget_group_get_expanded       (GladeWidgetGroup *group);
 
 const GList  *glade_widget_group_get_adaptors       (GladeWidgetGroup *group);
 
-gboolean      glade_catalog_convert_project         (GladeCatalog     *catalog,
-						     GladeProject     *project,
-						     GladeProjectFormat  new_format);
-
-
 gboolean      glade_catalog_supports_libglade       (GladeCatalog     *catalog);
 gboolean      glade_catalog_supports_gtkbuilder     (GladeCatalog     *catalog);
 
