@@ -83,9 +83,11 @@ enum
   PROP_ITEM_APPEARANCE,
   PROP_USE_SMALL_ITEM_ICONS,
   PROP_SHOW_SELECTOR_BUTTON,
-  PROP_PROJECT
+  PROP_PROJECT,
+  N_PROPERTIES
 };
 
+static GParamSpec *properties[N_PROPERTIES];
 static guint glade_palette_signals[LAST_SIGNAL] = { 0 };
 
 static void glade_palette_append_item_group (GladePalette        *palette,
@@ -121,13 +123,8 @@ palette_item_refresh_cb (GladePalette *palette,
       gtk_widget_set_sensitive (GTK_WIDGET (item),
                                 !(support & GLADE_SUPPORT_MISMATCH));
 
-      if (support & GLADE_SUPPORT_DEPRECATED)
-        /* XXX Todo, draw a cross overlaying the widget icon */
-        gtk_tool_button_set_stock_id (GTK_TOOL_BUTTON (item),
-                                      GTK_STOCK_DIALOG_WARNING);
-      else
-        gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (item),
-                                       glade_widget_adaptor_get_icon_name (adaptor));
+      gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (item),
+				     glade_widget_adaptor_get_icon_name (adaptor));
 
       /* prepend widget title */
       text = g_strdup_printf ("%s: %s", glade_widget_adaptor_get_title (adaptor), warning);
@@ -331,7 +328,7 @@ glade_palette_new_item (GladePalette * palette, GladeWidgetAdaptor * adaptor)
   gtk_widget_show (item);
 
   g_hash_table_insert (palette->priv->button_table, 
-		       g_strdup (glade_widget_adaptor_get_name (adaptor)), 
+		       (gchar *)glade_widget_adaptor_get_name (adaptor),
 		       item);
 
   return item;
@@ -594,38 +591,37 @@ glade_palette_class_init (GladePaletteClass * klass)
                     G_STRUCT_OFFSET (GladePaletteClass, refresh),
                     NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
 
-  g_object_class_install_property (object_class,
-                                   PROP_PROJECT,
-                                   g_param_spec_object ("project",
-							"Project",
-							"This palette's current project",
-							GLADE_TYPE_PROJECT,
-							G_PARAM_READWRITE));
+  properties[PROP_PROJECT] =
+    g_param_spec_object ("project",
+                         "Project",
+                         "This palette's current project",
+                         GLADE_TYPE_PROJECT,
+                         G_PARAM_READWRITE);
 
-  g_object_class_install_property (object_class,
-                                   PROP_ITEM_APPEARANCE,
-                                   g_param_spec_enum ("item-appearance",
-                                                      "Item Appearance",
-                                                      "The appearance of the palette items",
-                                                      GLADE_TYPE_ITEM_APPEARANCE,
-                                                      GLADE_ITEM_ICON_ONLY,
-                                                      G_PARAM_READWRITE));
+  properties[PROP_ITEM_APPEARANCE] =
+    g_param_spec_enum ("item-appearance",
+                       "Item Appearance",
+                       "The appearance of the palette items",
+                       GLADE_TYPE_ITEM_APPEARANCE,
+                       GLADE_ITEM_ICON_ONLY,
+                       G_PARAM_READWRITE);
 
-  g_object_class_install_property (object_class,
-                                   PROP_ITEM_APPEARANCE,
-                                   g_param_spec_boolean ("use-small-item-icons",
-                                                         "Use Small Item Icons",
-                                                         "Whether to use small icons to represent items",
-                                                         FALSE,
-                                                         G_PARAM_READWRITE));
+  properties[PROP_USE_SMALL_ITEM_ICONS] =
+    g_param_spec_boolean ("use-small-item-icons",
+                          "Use Small Item Icons",
+                          "Whether to use small icons to represent items",
+                          FALSE,
+                          G_PARAM_READWRITE);
 
-  g_object_class_install_property (object_class,
-                                   PROP_ITEM_APPEARANCE,
-                                   g_param_spec_boolean ("show-selector-button",
-                                                         "Show Selector Button",
-                                                         "Whether to show the internal selector button",
-                                                         TRUE,
-                                                         G_PARAM_READWRITE));
+  properties[PROP_SHOW_SELECTOR_BUTTON] =
+    g_param_spec_boolean ("show-selector-button",
+                          "Show Selector Button",
+                          "Whether to show the internal selector button",
+                          TRUE,
+                          G_PARAM_READWRITE);
+
+  /* Install all properties */
+  g_object_class_install_properties (object_class, N_PROPERTIES, properties);
 
   g_type_class_add_private (object_class, sizeof (GladePalettePrivate));
 }
@@ -638,8 +634,7 @@ glade_palette_init (GladePalette * palette)
 
   priv = palette->priv = GLADE_PALETTE_GET_PRIVATE (palette);
 
-  priv->button_table = g_hash_table_new_full (g_str_hash, g_str_equal,
-					      (GDestroyNotify)g_free, NULL);
+  priv->button_table = g_hash_table_new (g_str_hash, g_str_equal);
 
   priv->item_appearance      = GLADE_ITEM_ICON_ONLY;
   priv->use_small_item_icons = FALSE;
@@ -751,7 +746,7 @@ glade_palette_set_project (GladePalette *palette,
 
       glade_palette_refresh (palette);
 
-      g_object_notify (G_OBJECT (palette), "project");
+      g_object_notify_by_pspec (G_OBJECT (palette), properties[PROP_PROJECT]);
     }
 }
 
@@ -778,7 +773,7 @@ glade_palette_set_item_appearance (GladePalette * palette,
 
       glade_palette_update_appearance (palette);
 
-      g_object_notify (G_OBJECT (palette), "item-appearance");
+      g_object_notify_by_pspec (G_OBJECT (palette), properties[PROP_ITEM_APPEARANCE]);
     }
 }
 
@@ -803,7 +798,7 @@ glade_palette_set_use_small_item_icons (GladePalette * palette,
 
       glade_palette_update_appearance (palette);
 
-      g_object_notify (G_OBJECT (palette), "use-small-item-icons");
+      g_object_notify_by_pspec (G_OBJECT (palette), properties[PROP_USE_SMALL_ITEM_ICONS]);
 
     }
 
@@ -831,7 +826,7 @@ glade_palette_set_show_selector_button (GladePalette * palette,
       else
         gtk_widget_hide (priv->selector_hbox);
 
-      g_object_notify (G_OBJECT (palette), "show-selector-button");
+      g_object_notify_by_pspec (G_OBJECT (palette), properties[PROP_SHOW_SELECTOR_BUTTON]);
 
     }
 
