@@ -129,9 +129,11 @@ enum
   PROP_I18N_TRANSLATABLE,
   PROP_I18N_CONTEXT,
   PROP_I18N_COMMENT,
-  PROP_STATE
+  PROP_STATE,
+  N_PROPERTIES
 };
 
+static GParamSpec *properties[N_PROPERTIES];
 static guint glade_property_signals[LAST_SIGNAL] = { 0 };
 
 static GObjectClass *parent_class = NULL;
@@ -281,7 +283,7 @@ glade_property_fix_state (GladeProperty * property)
   if (property->priv->support_disabled)
     property->priv->state |= GLADE_STATE_SUPPORT_DISABLED;
 
-  g_object_notify (G_OBJECT (property), "state");
+  g_object_notify_by_pspec (G_OBJECT (property), properties[PROP_STATE]);
 }
 
 
@@ -367,6 +369,21 @@ glade_property_set_value_impl (GladeProperty * property, const GValue * value)
       glade_project_verify_property (property);
     }
 
+  /* Special case parentless widget properties */
+  if (glade_property_class_parentless_widget (property->priv->klass))
+    {
+      GladeWidget *gobj;
+      GObject *obj;
+      
+      if ((obj = g_value_get_object (&old_value)) &&
+          (gobj = glade_widget_get_from_gobject (obj)))
+        glade_widget_show (gobj);
+
+      if ((obj = g_value_get_object (value)) &&
+          (gobj = glade_widget_get_from_gobject (obj)))
+        glade_widget_hide (gobj);  
+    }
+
   g_value_unset (&old_value);
   return TRUE;
 }
@@ -605,51 +622,56 @@ glade_property_klass_init (GladePropertyKlass * prop_class)
   prop_class->tooltip_changed = NULL;
 
   /* Properties */
-  g_object_class_install_property
-      (object_class, PROP_CLASS,
-       g_param_spec_pointer
-       ("class", _("Class"),
-        _("The GladePropertyClass for this property"),
-        G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+  properties[PROP_CLASS] =
+    g_param_spec_pointer ("class",
+                          _("Class"),
+                          _("The GladePropertyClass for this property"),
+                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE);
 
-  g_object_class_install_property
-      (object_class, PROP_ENABLED,
-       g_param_spec_boolean
-       ("enabled", _("Enabled"),
-        _("If the property is optional, this is its enabled state"),
-        TRUE, G_PARAM_READWRITE));
+  properties[PROP_ENABLED] =
+    g_param_spec_boolean ("enabled",
+                          _("Enabled"),
+                          _("If the property is optional, this is its enabled state"),
+                          TRUE, G_PARAM_READWRITE);
 
-  g_object_class_install_property
-      (object_class, PROP_SENSITIVE,
-       g_param_spec_boolean
-       ("sensitive", _("Sensitive"),
-        _("This gives backends control to set property sensitivity"),
-        TRUE, G_PARAM_READWRITE));
+  properties[PROP_SENSITIVE] =
+    g_param_spec_boolean ("sensitive",
+                          _("Sensitive"),
+                          _("This gives backends control to set property sensitivity"),
+                          TRUE, G_PARAM_READWRITE);
 
-  g_object_class_install_property
-      (object_class, PROP_I18N_CONTEXT,
-       g_param_spec_string
-       ("i18n-context", _("Context"),
-        _("Context for translation"), NULL, G_PARAM_READWRITE));
+  properties[PROP_I18N_CONTEXT] =
+    g_param_spec_string ("i18n-context",
+                         _("Context"),
+                         _("Context for translation"),
+                         NULL,
+                         G_PARAM_READWRITE);
 
-  g_object_class_install_property
-      (object_class, PROP_I18N_COMMENT,
-       g_param_spec_string
-       ("i18n-comment", _("Comment"),
-        _("Comment for translators"), NULL, G_PARAM_READWRITE));
+  properties[PROP_I18N_COMMENT] =
+    g_param_spec_string ("i18n-comment",
+                         _("Comment"),
+                         _("Comment for translators"),
+                         NULL,
+                         G_PARAM_READWRITE);
 
-  g_object_class_install_property
-      (object_class, PROP_I18N_TRANSLATABLE,
-       g_param_spec_boolean
-       ("i18n-translatable", _("Translatable"),
-        _("Whether this property is translatable"), TRUE, G_PARAM_READWRITE));
+  properties[PROP_I18N_TRANSLATABLE] =
+    g_param_spec_boolean ("i18n-translatable",
+                          _("Translatable"),
+                          _("Whether this property is translatable"),
+                          TRUE,
+                          G_PARAM_READWRITE);
 
-  g_object_class_install_property
-      (object_class, PROP_STATE,
-       g_param_spec_int
-       ("state", _("Visual State"),
-        _("Priority information for the property editor to act on"),
-        GLADE_STATE_NORMAL, G_MAXINT, GLADE_STATE_NORMAL, G_PARAM_READABLE));
+  properties[PROP_STATE] =
+    g_param_spec_int ("state",
+                      _("Visual State"),
+                      _("Priority information for the property editor to act on"),
+                      GLADE_STATE_NORMAL,
+                      G_MAXINT,
+                      GLADE_STATE_NORMAL,
+                      G_PARAM_READABLE);
+  
+  /* Install all properties */
+  g_object_class_install_properties (object_class, N_PROPERTIES, properties);
 
   /* Signal */
   glade_property_signals[VALUE_CHANGED] =
@@ -659,7 +681,7 @@ glade_property_klass_init (GladePropertyKlass * prop_class)
                     G_STRUCT_OFFSET (GladePropertyKlass,
                                      value_changed),
                     NULL, NULL,
-                    glade_marshal_VOID__POINTER_POINTER,
+                    _glade_marshal_VOID__POINTER_POINTER,
                     G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
   glade_property_signals[TOOLTIP_CHANGED] =
@@ -669,7 +691,7 @@ glade_property_klass_init (GladePropertyKlass * prop_class)
                     G_STRUCT_OFFSET (GladePropertyKlass,
                                      tooltip_changed),
                     NULL, NULL,
-                    glade_marshal_VOID__STRING_STRING_STRING,
+                    _glade_marshal_VOID__STRING_STRING_STRING,
                     G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_STRING,
                     G_TYPE_STRING);
 
@@ -1099,6 +1121,11 @@ glade_property_read (GladeProperty * property,
     }
   else
     {
+      /* If an optional property is specified in the
+       * glade file, its enabled
+       */
+      property->priv->enabled = TRUE;
+
       gvalue = 
 	glade_property_class_make_gvalue_from_string (property->priv->klass, value, project);
 
@@ -1106,11 +1133,6 @@ glade_property_read (GladeProperty * property,
 
       g_value_unset (gvalue);
       g_free (gvalue);
-
-      /* If an optional property is specified in the
-       * glade file, its enabled
-       */
-      property->priv->enabled = TRUE;
     }
 
   translatable =
@@ -1318,7 +1340,7 @@ glade_property_i18n_set_comment (GladeProperty * property, const gchar * str)
     g_free (property->priv->i18n_comment);
 
   property->priv->i18n_comment = g_strdup (str);
-  g_object_notify (G_OBJECT (property), "i18n-comment");
+  g_object_notify_by_pspec (G_OBJECT (property), properties[PROP_I18N_COMMENT]);
 }
 
 G_CONST_RETURN gchar *
@@ -1336,7 +1358,7 @@ glade_property_i18n_set_context (GladeProperty * property, const gchar * str)
     g_free (property->priv->i18n_context);
 
   property->priv->i18n_context = g_strdup (str);
-  g_object_notify (G_OBJECT (property), "i18n-context");
+  g_object_notify_by_pspec (G_OBJECT (property), properties[PROP_I18N_CONTEXT]);
 }
 
 G_CONST_RETURN gchar *
@@ -1352,7 +1374,7 @@ glade_property_i18n_set_translatable (GladeProperty * property,
 {
   g_return_if_fail (GLADE_IS_PROPERTY (property));
   property->priv->i18n_translatable = translatable;
-  g_object_notify (G_OBJECT (property), "i18n-translatable");
+  g_object_notify_by_pspec (G_OBJECT (property), properties[PROP_I18N_TRANSLATABLE]);
 }
 
 gboolean
@@ -1392,7 +1414,7 @@ glade_property_set_sensitive (GladeProperty * property,
                      property->priv->insensitive_tooltip, 
 		     property->priv->support_warning);
     }
-  g_object_notify (G_OBJECT (property), "sensitive");
+  g_object_notify_by_pspec (G_OBJECT (property), properties[PROP_SENSITIVE]);
 }
 
 G_CONST_RETURN gchar *
@@ -1486,7 +1508,7 @@ glade_property_set_enabled (GladeProperty * property, gboolean enabled)
 
   glade_property_fix_state (property);
 
-  g_object_notify (G_OBJECT (property), "enabled");
+  g_object_notify_by_pspec (G_OBJECT (property), properties[PROP_ENABLED]);
 }
 
 gboolean
