@@ -62,8 +62,7 @@ gchar            *glade_utils_flags_string_from_value_displayable (GType flags_t
 gchar            *glade_utils_enum_string_from_value_displayable (GType flags_type, gint value);
 GValue           *glade_utils_value_from_string   (GType               type,
 						   const gchar        *string,
-						   GladeProject       *project,
-						   GladeWidget        *widget);
+						   GladeProject       *project);
 gchar            *glade_utils_string_from_value   (const GValue       *value);
 
 /* Devhelp */
@@ -98,8 +97,6 @@ void              glade_utils_cairo_draw_rectangle (cairo_t *cr,
 						    gint width,
 						    gint height);
 
-void              glade_util_draw_selection_nodes (GtkWidget* expose_widget, cairo_t *cr);
-
 /* Lists */
 GList            *glade_util_purify_list           (GList        *list);
 GList            *glade_util_added_in_list         (GList        *old_list,
