@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008 Tristan Van Berkom.
  *
- * This library is free software; you can redistribute it and/or it
+ * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
@@ -33,7 +33,7 @@
 GladeModelData *
 glade_model_data_new (GType type, const gchar * column_name)
 {
-  GladeModelData *data = g_new0 (GladeModelData, 1);
+  GladeModelData *data = g_slice_new0 (GladeModelData);
 
   if (type != 0)
     g_value_init (&data->value, type);
@@ -49,10 +49,12 @@ glade_model_data_new (GType type, const gchar * column_name)
 GladeModelData *
 glade_model_data_copy (GladeModelData * data)
 {
+  GladeModelData *dup;
+
   if (!data)
     return NULL;
 
-  GladeModelData *dup = g_new0 (GladeModelData, 1);
+  dup = g_slice_new0 (GladeModelData);
 
   if (G_VALUE_TYPE (&data->value) != 0)
     {
@@ -80,7 +82,7 @@ glade_model_data_free (GladeModelData * data)
       g_free (data->name);
       g_free (data->i18n_context);
       g_free (data->i18n_comment);
-      g_free (data);
+      g_slice_free (GladeModelData, data);
     }
 }
 
@@ -90,10 +92,12 @@ glade_model_data_tree_copy (GNode * node)
   return g_node_copy_deep (node, (GCopyFunc) glade_model_data_copy, NULL);
 }
 
-static void
+static gboolean
 model_data_traverse_free (GNode * node, gpointer data)
 {
   glade_model_data_free ((GladeModelData *) node->data);
+
+  return FALSE;
 }
 
 void
@@ -306,11 +310,19 @@ static gboolean
 update_data_tree_idle (GladeEditorProperty * eprop)
 {
   GladeEPropModelData *eprop_data = GLADE_EPROP_MODEL_DATA (eprop);
+  GladeProperty       *property = glade_editor_property_get_property (eprop);
   GValue value = { 0, };
 
   g_value_init (&value, GLADE_TYPE_MODEL_DATA_TREE);
   g_value_take_boxed (&value, eprop_data->pending_data_tree);
-  glade_editor_property_commit (eprop, &value);
+
+  /* Only commit the value if it changed, otherwise this
+   * can trigger a load.. which we dont handle well in this
+   * editor 
+   */
+  if (!glade_property_equals_value (property, &value))
+    glade_editor_property_commit (eprop, &value);
+
   g_value_unset (&value);
 
   eprop_data->pending_data_tree = NULL;
@@ -711,14 +723,11 @@ value_text_edited (GtkCellRendererText * cell,
                                            glade_get_value_from_displayable
                                            (G_VALUE_TYPE (&data->value),
                                             new_text),
-                                           glade_widget_get_project
-					   (glade_property_get_widget (property)),
-                                           glade_property_get_widget (property));
+                                           glade_widget_get_project (glade_property_get_widget (property)));
   else
     value =
         glade_utils_value_from_string (G_VALUE_TYPE (&data->value), new_text,
-                                       glade_widget_get_project (glade_property_get_widget (property)),
-                                       glade_property_get_widget (property));
+                                       glade_widget_get_project (glade_property_get_widget (property)));
 
 
   g_value_copy (value, &data->value);
