@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008 Tristan Van Berkom.
  *
- * This library is free software; you can redistribute it and/or it
+ * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
@@ -39,8 +39,6 @@ struct _GladeTreeViewEditor
 {
 	GtkHBox  parent;
 
-	GladeWidget *loaded_widget; /* A handy pointer to the loaded widget ... */
-
 	GtkWidget *embed;
 	GtkWidget *embed_list_store;
 	GtkWidget *embed_tree_store;
